@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2018, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2019, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -298,3 +298,12 @@ int xopen_write(const char * path)
               S_IRUSR | S_IWUSR);
 #endif
 }
+
+const char * xstrcasestr(const char * haystack, const char * needle)
+{
+#ifdef _WIN32
+  return StrStrIA(haystack, needle);
+#else
+  return strcasestr(haystack, needle);
+#endif
+}
