@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2018, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2019, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -232,7 +232,7 @@ int find_best_parents(struct chimera_info_s * ci)
             case 'M':
               for(int k=0; k<run; k++)
                 {
-                  if (chrmap_4bit[(int)(qseq[qpos])] ==
+                  if (chrmap_4bit[(int)(qseq[qpos])] &
                       chrmap_4bit[(int)(tseq[tpos])])
                     ci->match[i * ci->query_len + qpos] = 1;
                   qpos++;
@@ -510,9 +510,9 @@ int eval_parents(struct chimera_info_s * ci)
 
   for(int i = 0; i < alnlen; i++)
     {
-      char qsym  = chrmap_4bit[(int)(ci->qaln   [i])];
-      char p1sym = chrmap_4bit[(int)(ci->paln[0][i])];
-      char p2sym = chrmap_4bit[(int)(ci->paln[1][i])];
+      unsigned int qsym  = chrmap_4bit[(int)(ci->qaln   [i])];
+      unsigned int p1sym = chrmap_4bit[(int)(ci->paln[0][i])];
+      unsigned int p2sym = chrmap_4bit[(int)(ci->paln[1][i])];
 
       /* mark positions to ignore in voting */
 
@@ -526,8 +526,10 @@ int eval_parents(struct chimera_info_s * ci)
             ci->ignore[i+1] = 1;
         }
 
-      /* ignore ambigous symbols */
-      if ((qsym>4) || (p1sym>4) || (p2sym>4))
+      /* ignore ambiguous symbols */
+      if ((ambiguous_4bit[qsym]) ||
+          (ambiguous_4bit[p1sym]) ||
+          (ambiguous_4bit[p2sym]))
         ci->ignore[i] = 1;
 
       /* lower case parent symbols that differ from query */
@@ -812,27 +814,27 @@ int eval_parents(struct chimera_info_s * ci)
           fprintf(fp_uchimealns, "Query   (%5d nt) ",
                   ci->query_len);
           if (opt_xsize)
-            abundance_fprint_header_strip_size(fp_uchimealns,
-                                               ci->query_head,
-                                               ci->query_head_len);
+            header_fprint_strip_size(fp_uchimealns,
+                                     ci->query_head,
+                                     ci->query_head_len);
           else
             fprintf(fp_uchimealns, "%s", ci->query_head);
 
           fprintf(fp_uchimealns, "\nParentA (%5" PRIu64 " nt) ",
                   db_getsequencelen(seqno_a));
           if (opt_xsize)
-            abundance_fprint_header_strip_size(fp_uchimealns,
-                                               db_getheader(seqno_a),
-                                               db_getheaderlen(seqno_a));
+            header_fprint_strip_size(fp_uchimealns,
+                                     db_getheader(seqno_a),
+                                     db_getheaderlen(seqno_a));
           else
             fprintf(fp_uchimealns, "%s", db_getheader(seqno_a));
 
           fprintf(fp_uchimealns, "\nParentB (%5" PRIu64 " nt) ",
                   db_getsequencelen(seqno_b));
           if (opt_xsize)
-            abundance_fprint_header_strip_size(fp_uchimealns,
-                                               db_getheader(seqno_b),
-                                               db_getheaderlen(seqno_b));
+            header_fprint_strip_size(fp_uchimealns,
+                                     db_getheader(seqno_b),
+                                     db_getheaderlen(seqno_b));
           else
             fprintf(fp_uchimealns, "%s", db_getheader(seqno_b));
           fprintf(fp_uchimealns, "\n\n");
@@ -911,17 +913,17 @@ int eval_parents(struct chimera_info_s * ci)
 
           if (opt_xsize)
             {
-              abundance_fprint_header_strip_size(fp_uchimeout,
-                                                 ci->query_head,
-                                                 ci->query_head_len);
+              header_fprint_strip_size(fp_uchimeout,
+                                       ci->query_head,
+                                       ci->query_head_len);
               fprintf(fp_uchimeout, "\t");
-              abundance_fprint_header_strip_size(fp_uchimeout,
-                                                 db_getheader(seqno_a),
-                                                 db_getheaderlen(seqno_a));
+              header_fprint_strip_size(fp_uchimeout,
+                                       db_getheader(seqno_a),
+                                       db_getheaderlen(seqno_a));
               fprintf(fp_uchimeout, "\t");
-              abundance_fprint_header_strip_size(fp_uchimeout,
-                                                 db_getheader(seqno_b),
-                                                 db_getheaderlen(seqno_b));
+              header_fprint_strip_size(fp_uchimeout,
+                                       db_getheader(seqno_b),
+                                       db_getheaderlen(seqno_b));
               fprintf(fp_uchimeout, "\t");
             }
           else
@@ -938,13 +940,13 @@ int eval_parents(struct chimera_info_s * ci)
               if (opt_xsize)
                 {
                   if (QA >= QB)
-                    abundance_fprint_header_strip_size(fp_uchimeout,
-                                                       db_getheader(seqno_a),
-                                                       db_getheaderlen(seqno_a));
+                    header_fprint_strip_size(fp_uchimeout,
+                                             db_getheader(seqno_a),
+                                             db_getheaderlen(seqno_a));
                   else
-                    abundance_fprint_header_strip_size(fp_uchimeout,
-                                                       db_getheader(seqno_b),
-                                                       db_getheaderlen(seqno_b));
+                    header_fprint_strip_size(fp_uchimeout,
+                                             db_getheader(seqno_b),
+                                             db_getheaderlen(seqno_b));
                   fprintf(fp_uchimeout, "\t");
                 }
               else
@@ -1343,6 +1345,7 @@ uint64_t chimera_thread_core(struct chimera_info_s * ci)
                                 ci->query_head_len,
                                 ci->query_size,
                                 chimera_count,
+                                -1.0,
                                 -1,
                                 -1,
                                 opt_fasta_score ?
@@ -1365,6 +1368,7 @@ uint64_t chimera_thread_core(struct chimera_info_s * ci)
                                 ci->query_head_len,
                                 ci->query_size,
                                 borderline_count,
+                                -1.0,
                                 -1,
                                 -1,
                                 opt_fasta_score ?
@@ -1384,9 +1388,9 @@ uint64_t chimera_thread_core(struct chimera_info_s * ci)
               fprintf(fp_uchimeout, "0.0000\t");
 
               if (opt_xsize)
-                abundance_fprint_header_strip_size(fp_uchimeout,
-                                                   ci->query_head,
-                                                   ci->query_head_len);
+                header_fprint_strip_size(fp_uchimeout,
+                                         ci->query_head,
+                                         ci->query_head_len);
               else
                 fprintf(fp_uchimeout, "%s", ci->query_head);
 
@@ -1411,6 +1415,7 @@ uint64_t chimera_thread_core(struct chimera_info_s * ci)
                                 ci->query_head_len,
                                 ci->query_size,
                                 nonchimera_count,
+                                -1.0,
                                 -1,
                                 -1,
                                 opt_fasta_score ?
@@ -1505,15 +1510,17 @@ void chimera()
   opt_maxaccepts = few;
   opt_maxrejects = rejects;
   opt_id = chimera_id;
-  opt_strand = 1;
-  opt_self = 1;
-  opt_selfid = 1;
+
+  if (opt_strand != 1)
+    fatal("Only --strand plus is allowed with uchime_ref.");
 
   if (opt_uchime_denovo || opt_uchime2_denovo || opt_uchime3_denovo)
-    opt_threads = 1;
-
-  if (opt_uchime_denovo || opt_uchime2_denovo || opt_uchime3_denovo)
-    opt_maxsizeratio = 1.0 / opt_abskew;
+    {
+      opt_self = 1;
+      opt_selfid = 1;
+      opt_threads = 1;
+      opt_maxsizeratio = 1.0 / opt_abskew;
+    }
 
   tophits = opt_maxaccepts + opt_maxrejects;
 
