@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2018, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2019, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -59,14 +59,14 @@
 */
 
 #ifdef __x86_64__
-void increment_counters_from_bitmap_sse2(unsigned short * counters,
+void increment_counters_from_bitmap_sse2(count_t * counters,
                                          unsigned char * bitmap,
                                          unsigned int totalbits);
-void increment_counters_from_bitmap_ssse3(unsigned short * counters,
+void increment_counters_from_bitmap_ssse3(count_t * counters,
                                           unsigned char * bitmap,
                                           unsigned int totalbits);
 #else
-void increment_counters_from_bitmap(unsigned short * counters,
+void increment_counters_from_bitmap(count_t * counters,
                                     unsigned char * bitmap,
                                     unsigned int totalbits);
 #endif
