@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2018, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2019, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -72,6 +72,7 @@ char * fastq_get_header(fastx_handle h);
 char * fastq_get_sequence(fastx_handle h);
 char * fastq_get_quality(fastx_handle h);
 int64_t fastq_get_abundance(fastx_handle h);
+int64_t fastq_get_abundance_and_presence(fastx_handle h);
 uint64_t fastq_get_header_length(fastx_handle h);
 uint64_t fastq_get_sequence_length(fastx_handle h);
 uint64_t fastq_get_quality_length(fastx_handle h);
@@ -86,5 +87,4 @@ void fastq_print_general(FILE * fp,
                          char * quality,
                          int abundance,
                          int ordinal,
-                         const char * score_name,
-                         double score);
+                         double ee);
