@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2018, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2019, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -60,289 +60,6 @@
 
 #include "vsearch.h"
 
-int fastq_get_qual(char q)
-{
-  int qual = q - opt_fastq_ascii;
-  char msg[200];
-
-  if (qual < opt_fastq_qmin)
-    {
-      snprintf(msg, 200, "FASTQ quality value (%d) below qmin (%" PRId64 ")",
-               qual, opt_fastq_qmin);
-      fatal(msg);
-    }
-  else if (qual > opt_fastq_qmax)
-    {
-      snprintf(msg, 200, "FASTQ quality value (%d) above qmax (%" PRId64 ")",
-               qual, opt_fastq_qmax);
-      fatal(msg);
-    }
-  return qual;
-}
-
-void filter(bool fastq_only, char * filename)
-{
-  fastx_handle h = fastx_open(filename);
-
-  if (!h)
-    fatal("Unrecognized file type (not proper FASTA or FASTQ format)");
-
-  if (fastq_only && ! h->is_fastq)
-    fatal("FASTA input files not allowed with fastq_filter, consider using fastx_filter command instead");
-
-  if ((opt_fastqout || opt_fastqout_discarded) && ! h->is_fastq)
-    fatal("Cannot write FASTQ output with a FASTA input file, lacking quality scores");
-
-  uint64_t filesize = fastx_get_size(h);
-
-  FILE * fp_fastaout = 0;
-  FILE * fp_fastqout = 0;
-  FILE * fp_fastaout_discarded = 0;
-  FILE * fp_fastqout_discarded = 0;
-
-  if (opt_fastaout)
-    {
-      fp_fastaout = fopen_output(opt_fastaout);
-      if (!fp_fastaout)
-        fatal("Unable to open FASTA output file for writing");
-    }
-
-  if (opt_fastqout)
-    {
-      fp_fastqout = fopen_output(opt_fastqout);
-      if (!fp_fastqout)
-        fatal("Unable to open FASTQ output file for writing");
-    }
-
-  if (opt_fastaout_discarded)
-    {
-      fp_fastaout_discarded = fopen_output(opt_fastaout_discarded);
-      if (!fp_fastaout_discarded)
-        fatal("Unable to open FASTA output file for writing");
-    }
-
-  if (opt_fastqout_discarded)
-    {
-      fp_fastqout_discarded = fopen_output(opt_fastqout_discarded);
-      if (!fp_fastqout_discarded)
-        fatal("Unable to open FASTQ output file for writing");
-    }
-
-  uint64_t header_alloc = 0;
-  char * header = 0;
-  if (opt_relabel)
-    {
-      header_alloc = strlen(opt_relabel) + 25;
-      header = (char*) xmalloc(header_alloc);
-    }
-
-  progress_init("Reading input file", filesize);
-
-  int64_t kept = 0;
-  int64_t discarded = 0;
-  int64_t truncated = 0;
-
-  while(fastx_next(h, 0, chrmap_no_change))
-    {
-      int64_t length = fastx_get_sequence_length(h);
-      char * d = fastx_get_header(h);
-      char * p = fastx_get_sequence(h);
-      char * q = fastx_get_quality(h);
-      int64_t abundance = fastx_get_abundance(h);
-
-      /* strip initial part */
-      if (opt_fastq_stripleft > 0)
-        {
-          if (opt_fastq_stripleft < length)
-            {
-              p += opt_fastq_stripleft;
-              q += opt_fastq_stripleft;
-              length -= opt_fastq_stripleft;
-            }
-          else
-            {
-              p += length;
-              q += length;
-              length = 0;
-            }
-        }
-
-      /* strip right end */
-      if (opt_fastq_stripright > 0)
-        {
-          if (opt_fastq_stripright < length)
-            length -= opt_fastq_stripright;
-          else
-            length = 0;
-        }
-
-      /* truncate trailing part */
-      if (opt_fastq_trunclen >= 0)
-        {
-          if (length >= opt_fastq_trunclen)
-            length = opt_fastq_trunclen;
-          else
-            length = 0;
-        }
-
-      /* truncate trailing part, but keep if short */
-      if ((opt_fastq_trunclen_keep >= 0) && (length > opt_fastq_trunclen_keep))
-        length = opt_fastq_trunclen_keep;
-
-      /* quality and ee truncation */
-      double ee = 0.0;
-      if (h->is_fastq)
-        {
-          for (int64_t i = 0; i < length; i++)
-            {
-              int qual = fastq_get_qual(q[i]);
-              ee += exp10(- qual / 10.0);
-
-              if ((qual <= opt_fastq_truncqual) ||
-                  (ee > opt_fastq_truncee))
-                {
-                  ee -= exp10(- qual / 10.0);
-                  length = i;
-                  break;
-                }
-            }
-        }
-
-      /* count n's */
-      int64_t ncount = 0;
-      for (int64_t i = 0; i < length; i++)
-        {
-          int pc = p[i];
-          if ((pc == 'N') || (pc == 'n'))
-            ncount++;
-        }
-
-      if ((length >= opt_fastq_minlen) &&
-          (length <= opt_fastq_maxlen) &&
-          ((opt_fastq_trunclen < 0) || (length >= opt_fastq_trunclen)) &&
-          (ncount <= opt_fastq_maxns) &&
-          (ee <= opt_fastq_maxee) &&
-          ((length == 0) || (ee / length <= opt_fastq_maxee_rate)) &&
-          ((opt_minsize == 0) || (abundance >= opt_minsize)) &&
-          ((opt_maxsize == 0) || (abundance <= opt_maxsize)))
-        {
-          /* keep the sequence */
-
-          kept++;
-
-          if ((uint64_t)(length) < fastx_get_sequence_length(h))
-            {
-              truncated++;
-              p[length] = 0;
-              if (h->is_fastq)
-                q[length] = 0;
-            }
-
-          if (opt_fastaout)
-            fasta_print_general(fp_fastaout,
-                                0,
-                                p,
-                                length,
-                                d,
-                                fastx_get_header_length(h),
-                                abundance,
-                                kept,
-                                -1,
-                                -1,
-                                (opt_eeout || opt_fastq_eeout) ? "ee" : 0,
-                                ee);
-
-          if (opt_fastqout)
-            fastq_print_general(fp_fastqout,
-                                p,
-                                length,
-                                d,
-                                fastx_get_header_length(h),
-                                q,
-                                abundance,
-                                kept,
-                                (opt_eeout || opt_fastq_eeout) ? "ee" : 0,
-                                ee);
-        }
-      else
-        {
-          /* discard the sequence */
-
-          discarded++;
-
-          if (opt_fastaout_discarded)
-            fasta_print_general(fp_fastaout_discarded,
-                                0,
-                                p,
-                                length,
-                                d,
-                                fastx_get_header_length(h),
-                                abundance,
-                                discarded,
-                                -1,
-                                -1,
-                                (opt_eeout || opt_fastq_eeout) ? "ee" : 0,
-                                ee);
-
-          if (opt_fastqout_discarded)
-            fastq_print_general(fp_fastqout_discarded,
-                                p,
-                                length,
-                                d,
-                                fastx_get_header_length(h),
-                                q,
-                                abundance,
-                                discarded,
-                                (opt_eeout || opt_fastq_eeout) ? "ee" : 0,
-                                ee);
-        }
-
-      progress_update(fastx_get_position(h));
-    }
-  progress_done();
-
-  if (! opt_quiet)
-    fprintf(stderr,
-            "%" PRId64 " sequences kept (of which %" PRId64 " truncated), %" PRId64 " sequences discarded.\n",
-            kept,
-            truncated,
-            discarded);
-
-  if (opt_log)
-    fprintf(fp_log,
-            "%" PRId64 " sequences kept (of which %" PRId64 " truncated), %" PRId64 " sequences discarded.\n",
-            kept,
-            truncated,
-            discarded);
-
-  if (header)
-    xfree(header);
-
-  if (opt_fastaout)
-    fclose(fp_fastaout);
-
-  if (opt_fastqout)
-    fclose(fp_fastqout);
-
-  if (opt_fastaout_discarded)
-    fclose(fp_fastaout_discarded);
-
-  if (opt_fastqout_discarded)
-    fclose(fp_fastqout_discarded);
-
-  fastx_close(h);
-}
-
-void fastq_filter()
-{
-  filter(1, opt_fastq_filter);
-}
-
-void fastx_filter()
-{
-  filter(0, opt_fastx_filter);
-}
-
 void fastq_chars()
 {
   uint64_t sequence_chars[256];
@@ -456,7 +173,7 @@ void fastq_chars()
 
   char fastq_ascii, fastq_qmin, fastq_qmax;
 
-  if (qmin < 59)
+  if ((qmin < 59) || (qmax < 75))
     fastq_ascii = 33;
   else
     fastq_ascii = 64;
@@ -924,7 +641,10 @@ void fastq_stats()
 
   fastq_close(h);
 
-  fprintf(stderr, "Read %" PRIu64 " sequences.\n", seq_count);
+  if (!opt_quiet)
+    {
+        fprintf(stderr, "Read %" PRIu64 " sequences.\n", seq_count);
+    }
 }
 
 void fastx_revcomp()
@@ -1030,6 +750,7 @@ void fastx_revcomp()
                             hlen,
                             0,
                             count,
+                            -1.0,
                             -1, -1, 0, 0.0);
 
       if (opt_fastqout)
@@ -1041,7 +762,7 @@ void fastx_revcomp()
                             qual_buffer,
                             0,
                             count,
-                            0, 0.0);
+                            -1.0);
 
       progress_update(fastx_get_position(h));
     }
@@ -1077,6 +798,7 @@ void fastq_convert()
 
   progress_init("Reading FASTQ file", filesize);
 
+  int j = 1;
   while(fastq_next(h, 0, chrmap_no_change))
     {
       /* header */
@@ -1127,8 +849,10 @@ void fastq_convert()
         }
       quality[length] = 0;
 
-      fastq_print(fp_fastqout, header, sequence, quality);
+      int hlen = fastq_get_header_length(h);
+      fastq_print_general(fp_fastqout, sequence, length, header, hlen, quality, 0, j, -1.0);
 
+      j++;
       progress_update(fastq_get_position(h));
     }
 
