@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2018, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2019, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -61,6 +61,9 @@
 extern char sym_nt_2bit[5];
 extern char sym_nt_4bit[17];
 
+extern unsigned int ambiguous_4bit[16];
+
+extern unsigned int char_header_action[256];
 extern unsigned int char_fasta_action[256];
 extern unsigned int char_fq_action_seq[256];
 extern unsigned int char_fq_action_qual[256];
